public inbox for [email protected]
help / color / mirror / Atom feed[patch] Minor shutdown message grammar fix
2+ messages / 2 participants
[nested] [flat]
* [patch] Minor shutdown message grammar fix
@ 2018-06-08 03:59 Anthony DeBarros <[email protected]>
2018-06-08 07:45 ` Re: [patch] Minor shutdown message grammar fix Dave Page <[email protected]>
0 siblings, 1 reply; 2+ messages in thread
From: Anthony DeBarros @ 2018-06-08 03:59 UTC (permalink / raw)
To: pgadmin-hackers
Hi, dev team,
I'm surfacing to offer this minor patch to update the shutdown messaging in
the tray menu and various dialogs to use the two-word "shut down" when the
message context is a verb rather than the one-word noun usage "shutdown".
For context, see:
* https://blogs.msdn.microsoft.com/oldnewthing/20060912-03/?p=29773/
* https://crowwriter.com/2017/11/27/two-or-one-words-spelling-rules/
Apologies for being the grammar nitpicker, but it's my forte. :-)
Best,
Anthony
Attachments:
[application/octet-stream] shut_down_message.patch (4.1K, 3-shut_down_message.patch)
download | inline diff:
diff --git a/docs/en_US/desktop_deployment.rst b/docs/en_US/desktop_deployment.rst
index 7657896b..2a5e2f91 100644
--- a/docs/en_US/desktop_deployment.rst
+++ b/docs/en_US/desktop_deployment.rst
@@ -14,7 +14,7 @@ additional instances of pgAdmin are launched, a new browser tab will be opened
and be served by the existing instance of the server in order to minimise system
resource utilisation. Clicking the icon in the system tray will present a menu
offering options to open a new pgAdmin window, configure the runtime, view the
-server log and shutdown the server.
+server log and shut down the server.
.. note:: Pre-compiled and configured installation packages are available for
a number of platforms. These packages should be used by end-users whereever
@@ -68,7 +68,7 @@ semi-colon character, for example:
.. code-block:: bash
/Users/dpage/.virtualenvs/pgadmin4/lib/python2.7/site-packages/;/Users/dpage/python-libs/
-
+
The configuration settings are stored using the QSettings class in Qt, which
will use an INI file on Unix systems (~/.config/pgadmin/pgadmin4.conf),
a plist file on Mac OS X (~/Library/Preferences/org.pgadmin.pgadmin4.plist),
diff --git a/runtime/Server.cpp b/runtime/Server.cpp
index 3fc00395..bf7f0bc9 100644
--- a/runtime/Server.cpp
+++ b/runtime/Server.cpp
@@ -332,7 +332,7 @@ void Server::shutdown(QUrl url)
{
bool shotdown = shutdownServer(url);
if (!shotdown)
- setError(tr("Failed to shutdown application server thread."));
+ setError(tr("Failed to shut down application server thread."));
QThread::quit();
QThread::wait();
diff --git a/web/pgadmin/misc/__init__.py b/web/pgadmin/misc/__init__.py
index da28413a..55e3fe73 100644
--- a/web/pgadmin/misc/__init__.py
+++ b/web/pgadmin/misc/__init__.py
@@ -119,7 +119,7 @@ def explain_js():
##########################################################################
-# A special URL used to shutdown the server
+# A special URL used to shut down the server
##########################################################################
@blueprint.route("/shutdown", methods=('get', 'post'))
def shutdown():
^ permalink raw reply [nested|flat] 2+ messages in thread
* Re: [patch] Minor shutdown message grammar fix
2018-06-08 03:59 [patch] Minor shutdown message grammar fix Anthony DeBarros <[email protected]>
@ 2018-06-08 07:45 ` Dave Page <[email protected]>
0 siblings, 0 replies; 2+ messages in thread
From: Dave Page @ 2018-06-08 07:45 UTC (permalink / raw)
To: Anthony DeBarros <[email protected]>; +Cc: pgadmin-hackers
Thanks, patch applied.
On Fri, Jun 8, 2018 at 4:59 AM, Anthony DeBarros <[email protected]>
wrote:
> Hi, dev team,
>
> I'm surfacing to offer this minor patch to update the shutdown messaging
> in the tray menu and various dialogs to use the two-word "shut down" when
> the message context is a verb rather than the one-word noun usage
> "shutdown".
>
> For context, see:
>
> * https://blogs.msdn.microsoft.com/oldnewthing/20060912-03/?p=29773/
> * https://crowwriter.com/2017/11/27/two-or-one-words-spelling-rules/
>
> Apologies for being the grammar nitpicker, but it's my forte. :-)
>
> Best,
> Anthony
>
>
diff --git a/runtime/TrayIcon.cpp b/runtime/TrayIcon.cpp
index 1ac8718f..31eed5d2 100644
--- a/runtime/TrayIcon.cpp
+++ b/runtime/TrayIcon.cpp
@@ -22,7 +22,7 @@
TrayIcon::TrayIcon(QString logFile) :
m_logFile(logFile)
-{
+{
m_logWindow = NULL;
m_trayIcon = NULL;
@@ -148,7 +148,7 @@ void TrayIcon::createActions()
m_logAction = new QAction(tr("&View log..."), this);
connect(m_logAction, SIGNAL(triggered()), this, SLOT(onLog()));
- m_quitAction = new QAction(tr("&Shutdown server"), this);
+ m_quitAction = new QAction(tr("&Shut down server"), this);
m_quitAction->setEnabled(false);
connect(m_quitAction, SIGNAL(triggered()), this, SLOT(onQuit()));
}
@@ -206,7 +206,7 @@ void TrayIcon::onConfig()
if (needRestart)
{
- if (QMessageBox::Yes == QMessageBox::question(this, tr("Shutdown server?"), QString(tr("The %1 server must be restarted for changes to take effect. Do you want to shutdown the server now?")).arg(PGA_APP_NAME), QMessageBox::Yes | QMessageBox::No))
+ if (QMessageBox::Yes == QMessageBox::question(this, tr("Shut down server?"), QString(tr("The %1 server must be restarted for changes to take effect. Do you want to shut down the server now?")).arg(PGA_APP_NAME), QMessageBox::Yes | QMessageBox::No))
{
exit(0);
}
@@ -239,9 +239,9 @@ void TrayIcon::onLog()
// Exit
void TrayIcon::onQuit()
{
- if (QMessageBox::Yes == QMessageBox::question(this, tr("Shutdown server?"), QString(tr("Are you sure you want to shutdown the %1 server?")).arg(PGA_APP_NAME), QMessageBox::Yes | QMessageBox::No))
+ if (QMessageBox::Yes == QMessageBox::question(this, tr("Shut down server?"), QString(tr("Are you sure you want to shut down the %1 server?")).arg(PGA_APP_NAME), QMessageBox::Yes | QMessageBox::No))
{
// Emit the signal to shutdown the python server.
emit shutdownSignal(m_appServerUrl);
exit(0);
}
@@ -239,9 +239,9 @@ void TrayIcon::onLog()
{
- // Emit the signal to shutdown the python server.
+ // Emit the signal to shut down the python server.
emit shutdownSignal(m_appServerUrl);
exit(0);
--
Dave Page
Blog: http://pgsnake.blogspot.com
Twitter: @pgsnake
EnterpriseDB UK: http://www.enterprisedb.com
The Enterprise PostgreSQL Company
^ permalink raw reply [nested|flat] 2+ messages in thread
end of thread, other threads:[~2018-06-08 07:45 UTC | newest]
Thread overview: 2+ messages (download: mbox mbox.gz follow: Atom feed)
-- links below jump to the message on this page --
2018-06-08 03:59 [patch] Minor shutdown message grammar fix Anthony DeBarros <[email protected]>
2018-06-08 07:45 ` Dave Page <[email protected]>
This inbox is served by agora; see mirroring instructions
for how to clone and mirror all data and code used for this inbox